@@ -4,21 +4,20 @@
 modname = 'rememberme'
 distname = 'cubicweb-rememberme'
 
-numversion = (0, 1, 2)
+numversion = (0, 1, 3)
 version = '.'.join(str(num) for num in numversion)
 
-license = 'LCL'
-copyright = '''Copyright (c) 2010 LOGILAB S.A. (Paris, FRANCE).
-http://www.logilab.fr -- mailto:contact@logilab.fr'''
+license = 'LGPL'
 
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
-
-short_desc = 'an implementation of the Rembemer Me feature for cubicweb'
-long_desc = '''an implementation of the Rembemer Me feature for cubicweb'''
-
 web = 'http://www.cubicweb.org/project/%s' % distname
 
+short_desc = 'implementation of the Remember Me feature for the CubicWeb framework'
+
+__depends__ = {'cubicweb': '>= 3.8.0'}
+__recommends__ = {}
+
 
 from os import listdir as _listdir
 from os.path import join, isdir, exists, dirname
@@ -43,8 +42,3 @@ for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18
 # Note: here, you'll need to add subdirectories if you want
 # them to be included in the debian package
 
-__depends_cubes__ = {}
-__depends__ = {'cubicweb': '>= 3.6.1'}
-__use__ = ()
-__recommend__ = ()
-
