@@ -49,34 +49,36 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
         except ValueError:
             req.remove_cookie(cookie, '__cw_auth_cookie')
             raise authentication.NoAuthInfo()
+        print login, {'magicnumber': magic}
         return login, {'magicnumber': magic}
 
-    def authenticated(self, req, cnx, retreiver):
+    def authenticated(self, retreiver, req, cnx, login, authinfo):
         """callback when return authentication information have opened a
-        repository connection successfully:
+        repository connection successfully. Take care req has no session
+        attached yet, hence req.execute isn't available.
 
-        set authentication cookie for the next time
+        Here we set authentication cookie for the next time
         """
         if not (retreiver is self or '__setauthcookie' in req.form):
             return
-        if cnx.anonymous_connection:
-            return
         req.form.pop('__setauthcookie', None)
         user = cnx.user()
-        authentity = req.create_entity('CWAuthCookie',
-                                       magicnumber=randint(0, MAX_MAGIC_NUMBER),
-                                       lifetime=self.cookie_lifetime,
-                                       auth_cookie_for_user=user.eid)
+        cls = req.vreg['etypes'].etype_class('CWAuthCookie')
+        #  req has no session set yet
+        authentity = cls.cw_instantiate(cnx.cursor().execute,
+                                        magicnumber=randint(0, MAX_MAGIC_NUMBER),
+                                        lifetime=self.cookie_lifetime,
+                                        auth_cookie_for_user=user.eid)
         # we've to commit here, else cookie may be rollbacked by errors while
         # trying to set last_login_time in the CookieSessionHandler (eg for ldap
         # user at least).
-        req.cnx.commit()
+        cnx.commit()
         magicnum = authentity.magicnumber
         cookie = req.get_cookie()
         cookie['__cw_auth_cookie'] = '%s;__magic=%s' % (user.login, magicnum)
         req.set_cookie(cookie, '__cw_auth_cookie', maxage=None,
                        expires=date.today() + self.cookie_lifetime)
-        cnx.authinfo['magicnumber'] = magicnum
+        authinfo['magicnumber'] = magicnum
 
 
 # add remember me checkbox on the login form ###################################
@@ -111,11 +113,11 @@ class LogoutController(basecontrollers.LogoutController):
             # used one, doesn't seem like a bad idea
             self._cw.execute('DELETE CWAuthCookie X '
                              'WHERE X auth_cookie_for_user U, U eid %(u)s',
-                             {'u': self._cw.user.eid}, 'u')
+                             {'u': self._cw.user.eid})
             self._cw.cnx.commit()
         except:
-            import traceback
-            traceback.print_exc()
+            self.exception('error while deleting authentication cookie for %s',
+                           self._cw.user.login)
         return super(LogoutController, self).publish(rset)
 
 
